==> biostime-openapi-sdk-1.2.1.RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/member/MemberGetWsCustInfoResBean.java <==
package global.hh.openapi.sdk.api.bean.member;


/**
 * @description: 查询会员资料信息
 * @author: 777771
 * @date: 2021-11-19 11:11:14
 */
public class MemberGetWsCustInfoResBean {

        /**
         * 手机号码
         */
        private String mobile;

        /**
         * 会员生日
         */
        private String birthday;

        /**
         * 会员地址
         */
        private String address;

        /**
         * 会员宝宝信息
         */
        private Object[] kids;

        /**
         * 会员等级
         */
        private Object grade;

        /**
         * 付费卡类型
         */
        private Object card;

        /**
         * 已关注公众号
         */
        private Object[] wechatNums;

        /**
         * 积分记录
         */
        private Object[] points;

        /**
         * 订单
         */
        private Object[] orders;

    public MemberGetWsCustInfoResBean(){
    }

    public MemberGetWsCustInfoResBean(String mobile,String birthday,String address,Object[] kids,Object grade,Object card,Object[] wechatNums,Object[] points,Object[] orders){
        this.mobile=mobile;
        this.birthday=birthday;
        this.address=address;
        this.kids=kids;
        this.grade=grade;
        this.card=card;
        this.wechatNums=wechatNums;
        this.points=points;
        this.orders=orders;
    }

    private String getMobile() {
        return mobile;
    }

    private void setMobile(String mobile) {
        this.mobile = mobile;
    }
    private String getBirthday() {
        return birthday;
    }

    private void setBirthday(String birthday) {
        this.birthday = birthday;
    }
    private String getAddress() {
        return address;
    }

    private void setAddress(String address) {
        this.address = address;
    }
    private Object[] getKids() {
        return kids;
    }

    private void setKids(Object[] kids) {
        this.kids = kids;
    }
    private Object getGrade() {
        return grade;
    }

    private void setGrade(Object grade) {
        this.grade = grade;
    }
    private Object getCard() {
        return card;
    }

    private void setCard(Object card) {
        this.card = card;
    }
    private Object[] getWechatNums() {
        return wechatNums;
    }

    private void setWechatNums(Object[] wechatNums) {
        this.wechatNums = wechatNums;
    }
    private Object[] getPoints() {
        return points;
    }

    private void setPoints(Object[] points) {
        this.points = points;
    }
    private Object[] getOrders() {
        return orders;
    }

    private void setOrders(Object[] orders) {
        this.orders = orders;
    }
}

==> biostime-openapi-sdk-1.5.8.8-RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/member/MemberGetWsCustInfoResBean.java <==
package global.hh.openapi.sdk.api.bean.member;


/**
 * @description: 查询会员资料信息
 * @author: 13158
 * @date: 2021-44-19 11:44:54
 */
public class MemberGetWsCustInfoResBean {

        /**
         * 手机号码
         */
        private String mobile;

        /**
         * 会员生日
         */
        private String birthday;

        /**
         * 会员地址
         */
        private String address;

        /**
         * 会员宝宝信息
         */
        private Object[] kids;

        /**
         * 会员等级
         */
        private Object grade;

        /**
         * 付费卡类型
         */
        private Object card;

        /**
         * 已关注公众号
         */
        private Object[] wechatNums;

        /**
         * 积分记录
         */
        private Object[] points;

        /**
         * 订单
         */
        private Object[] orders;

    public MemberGetWsCustInfoResBean(){
    }

    public MemberGetWsCustInfoResBean(String mobile,String birthday,String address,Object[] kids,Object grade,Object card,Object[] wechatNums,Object[] points,Object[] orders){
        this.mobile=mobile;
        this.birthday=birthday;
        this.address=address;
        this.kids=kids;
        this.grade=grade;
        this.card=card;
        this.wechatNums=wechatNums;
        this.points=points;
        this.orders=orders;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }
    public String getBirthday() {
        return birthday;
    }

    public void setBirthday(String birthday) {
        this.birthday = birthday;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public Object[] getKids() {
        return kids;
    }

    public void setKids(Object[] kids) {
        this.kids = kids;
    }
    public Object getGrade() {
        return grade;
    }

    public void setGrade(Object grade) {
        this.grade = grade;
    }
    public Object getCard() {
        return card;
    }

    public void setCard(Object card) {
        this.card = card;
    }
    public Object[] getWechatNums() {
        return wechatNums;
    }

    public void setWechatNums(Object[] wechatNums) {
        this.wechatNums = wechatNums;
    }
    public Object[] getPoints() {
        return points;
    }

    public void setPoints(Object[] points) {
        this.points = points;
    }
    public Object[] getOrders() {
        return orders;
    }

    public void setOrders(Object[] orders) {
        this.orders = orders;
    }
}
